from setuptools import setup, find_packages

setup(
    name="windows-terminal",
    version="0.1.0",
    description="A test package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[],
)
